@@ -3,12 +3,12 @@
     <name>defaultlook</name>
     <message>
         <location filename="defaultlook.ui" line="20"/>
-        <location filename="defaultlook.cpp" line="55"/>
-        <location filename="defaultlook.cpp" line="467"/>
-        <location filename="defaultlook.cpp" line="474"/>
-        <location filename="defaultlook.cpp" line="491"/>
+        <location filename="defaultlook.cpp" line="58"/>
         <location filename="defaultlook.cpp" line="502"/>
-        <location filename="defaultlook.cpp" line="512"/>
+        <location filename="defaultlook.cpp" line="509"/>
+        <location filename="defaultlook.cpp" line="526"/>
+        <location filename="defaultlook.cpp" line="537"/>
+        <location filename="defaultlook.cpp" line="547"/>
         <source>MX Tweak</source>
         <translation>MX Ulepszenia</translation>
     </message>
@@ -51,7 +51,7 @@
     <message>
         <location filename="defaultlook.ui" line="223"/>
         <source>About</source>
-        <translation>O</translation>
+        <translation>O programie</translation>
     </message>
     <message>
         <location filename="defaultlook.ui" line="234"/>
@@ -141,9 +141,9 @@
     <message>
         <location filename="defaultlook.ui" line="446"/>
         <location filename="defaultlook.ui" line="549"/>
-        <location filename="defaultlook.ui" line="741"/>
-        <location filename="defaultlook.ui" line="860"/>
-        <location filename="defaultlook.ui" line="902"/>
+        <location filename="defaultlook.ui" line="740"/>
+        <location filename="defaultlook.ui" line="894"/>
+        <location filename="defaultlook.ui" line="936"/>
         <source>Apply</source>
         <translation>Zastosuj</translation>
     </message>
@@ -184,8 +184,8 @@
     </message>
     <message>
         <location filename="defaultlook.ui" line="589"/>
-        <source>Remove User Theme Sets</source>
-        <translation type="unfinished"/>
+        <source>Remove User Theme Set</source>
+        <translation>Usuń zestaw motywów użytkownika</translation>
     </message>
     <message>
         <location filename="defaultlook.ui" line="600"/>
@@ -194,203 +194,233 @@
     </message>
     <message>
         <location filename="defaultlook.ui" line="614"/>
-        <location filename="defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="760"/>
         <source>Compositor</source>
         <translation>Kompozytor</translation>
     </message>
     <message>
         <location filename="defaultlook.ui" line="635"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ustawienia kompozytora Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="638"/>
-        <source>Xfwm Settings</source>
-        <translation>Ustawienia Xfwm</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="662"/>
-        <source>None</source>
-        <translation>Żaden</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="667"/>
-        <source>Xfwm (Xfce) Compositor</source>
-        <translation>Kompozytor Xfwm (Xfce)</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="672"/>
-        <source>Compton </source>
-        <translation>Compton</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="680"/>
-        <source>Edit compton.conf directly in text editor</source>
-        <translation>Edytuj plik compton.conf bezpośrednio w edytorze tekstu</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="683"/>
-        <source>Edit compton.conf</source>
-        <translation>Edytuj compton.conf</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="714"/>
-        <source>Transparency and shadow options</source>
-        <translation>Opcje przezroczystości i cienia</translation>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="721"/>
         <source>Launch compton-conf configuration tool</source>
         <translation>Uruchom narzędzie konfiguracyjne compton-conf</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="724"/>
+        <location filename="defaultlook.ui" line="638"/>
         <source>Compton settings</source>
         <translation>Ustawienia Compton</translation>
     </message>
+    <message>
+        <location filename="defaultlook.ui" line="662"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ustawienia kompozytora Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="665"/>
+        <source>Xfwm Settings</source>
+        <translation>Ustawienia Xfwm</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="689"/>
+        <source>None</source>
+        <translation>Żaden</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="694"/>
+        <source>Xfwm (Xfce) Compositor</source>
+        <translation>Kompozytor Xfwm (Xfce)</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="699"/>
+        <source>Compton </source>
+        <translation>Compton</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="707"/>
+        <source>Edit compton.conf directly in text editor</source>
+        <translation>Edytuj plik compton.conf bezpośrednio w edytorze tekstu</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="710"/>
+        <source>Edit compton.conf</source>
+        <translation>Edytuj compton.conf</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="767"/>
+        <source>Transparency and shadow options</source>
+        <translation>Opcje przezroczystości i cienia</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="774"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <location filename="defaultlook.ui" line="777"/>
+        <source>VBlank</source>
+        <translation>VBlank</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="785"/>
+        <source>auto</source>
+        <translation>auto</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="790"/>
+        <source>glx</source>
+        <translation>glx</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="795"/>
+        <source>xpresent</source>
+        <translation>xpresent</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="800"/>
+        <source>off</source>
+        <translation>wyłącz</translation>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="811"/>
         <source>Config Options</source>
         <translation>Opcje konfiguracji</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="785"/>
+        <location filename="defaultlook.ui" line="819"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation>Zresetuj Lightdm (ekran logowania) do domyślnego motywu systemowego</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="792"/>
+        <location filename="defaultlook.ui" line="826"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
         <translation>Zresetuj spersonalizowane działania prawego przycisku myszy dla Thunara do domyślnych ustawień systemowych</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="799"/>
+        <location filename="defaultlook.ui" line="833"/>
         <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
         <translation>Użyj sterownika intel zamiast domyślnego sterownika &quot;modesetting&quot; (wymaga ponownego uruchomienia)</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="806"/>
+        <location filename="defaultlook.ui" line="840"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation>UWAGA: istniejący plik /etc/X11/xorg.conf.d/20-intel.conf zostanie skopiowany do folderu domowego</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="813"/>
+        <location filename="defaultlook.ui" line="847"/>
         <source>Use tearfree amdgpu option</source>
         <translation>Użyj opcji tearfree amdgpu </translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="820"/>
+        <location filename="defaultlook.ui" line="854"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation>          UWAGA: istniejący plik /etc/X11/xorg.conf.d/20-amd.conf zostanie skopiowany do folderu domowego</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="827"/>
+        <location filename="defaultlook.ui" line="861"/>
         <source>Use tearfree radeon driver option</source>
         <translation>Użyj opcji sterownika tearfree radeon</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="834"/>
+        <location filename="defaultlook.ui" line="868"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation>          UWAGA: istniejący plik /etc/X11/xorg.conf.d/20-radeon.conf zostanie skopiowany do folderu domowego</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="874"/>
+        <location filename="defaultlook.ui" line="908"/>
         <source>Other</source>
         <translation>Inne</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="882"/>
+        <location filename="defaultlook.ui" line="916"/>
         <source>Enable single-click on desktop</source>
         <translation>Włącz uruchamianie jednym kliknięciem na pulpicie</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="889"/>
+        <location filename="defaultlook.ui" line="923"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Włącz uruchamianie jednym kliknięciem w menedżerze plików Thunar</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="926"/>
+        <location filename="defaultlook.ui" line="960"/>
         <source>Show systray (notification area) frame</source>
         <translation>Pokaż ramkę zasobnika systemowego (obszar powiadomień)</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="933"/>
+        <location filename="defaultlook.ui" line="967"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Pokaż w panelu okna ze wszystkich obszarów roboczych</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="940"/>
+        <location filename="defaultlook.ui" line="974"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Pozwól na montowanie dysków wewnętrznych przez użytkowników innych niż root</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="947"/>
+        <location filename="defaultlook.ui" line="981"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Wyłącz skracanie długich nazw plików na pulpicie</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="954"/>
+        <location filename="defaultlook.ui" line="988"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Włącz opcję hibernacji w menu Wyloguj</translation>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="961"/>
+        <location filename="defaultlook.ui" line="995"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>uwaga: wybierając hibernację, swap musi być &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="466"/>
+        <location filename="defaultlook.cpp" line="501"/>
         <source>About MX Tweak</source>
         <translation>O programie MX Ulepszenia</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="467"/>
+        <location filename="defaultlook.cpp" line="502"/>
         <source>Version: </source>
         <translation>Wersja:</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="503"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Aplikacja do szybkiego zmieniania wyglądu i dostosowywania interfejsu do potrzeb użytkownika</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="470"/>
+        <location filename="defaultlook.cpp" line="505"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Prawa autorskie © MX Linux</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="471"/>
-        <location filename="defaultlook.cpp" line="474"/>
+        <location filename="defaultlook.cpp" line="506"/>
+        <location filename="defaultlook.cpp" line="509"/>
         <source>License</source>
         <translation>Licencja</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="472"/>
+        <location filename="defaultlook.cpp" line="507"/>
         <source>Cancel</source>
         <translation>Anuluj</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="503"/>
+        <location filename="defaultlook.cpp" line="538"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Gotowe! Firefox może wymagać ponownego uruchomienia, aby zmiany przyniosły efekt</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="513"/>
+        <location filename="defaultlook.cpp" line="548"/>
         <source>This app is Xfce-only</source>
         <translation>Ta aplikacja jest dostępna tylko w Xfce</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="655"/>
+        <location filename="defaultlook.cpp" line="690"/>
         <source>Panel settings</source>
         <translation>Ustawienia panelu</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="656"/>
+        <location filename="defaultlook.cpp" line="691"/>
         <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
         <translation>Twoje bieżące ustawienia panelu zostały zapisane w ukrytym folderze o nazwie .restore w twoim katalogu domowym (~/.restore/)</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="1073"/>
+        <location filename="defaultlook.cpp" line="1117"/>
         <source>Choose a theme set</source>
         <translation>Wybierz zestaw motywów</translation>
     </message>
@@ -407,8 +437,8 @@
     <name>theming_to_tweak</name>
     <message>
         <location filename="theming_to_tweak.ui" line="14"/>
-        <source>Dialog</source>
-        <translation>Okno dialogowe</translation>
+        <source>New Theme Set</source>
+        <translation>Nowy zestaw motywów</translation>
     </message>
     <message>
         <location filename="theming_to_tweak.ui" line="20"/>
@@ -420,7 +450,7 @@
     <name>window_buttons</name>
     <message>
         <location filename="window_buttons.ui" line="14"/>
-        <location filename="window_buttons.cpp" line="36"/>
+        <location filename="window_buttons.cpp" line="37"/>
         <source>Window Buttons</source>
         <translation>Przyciski okien</translation>
     </message>
@@ -560,7 +590,7 @@
     <message>
         <location filename="xfwm_compositor_settings.ui" line="14"/>
         <source>Dialog</source>
-        <translation>Dialog</translation>
+        <translation>Okno dialogowe</translation>
     </message>
     <message>
         <location filename="xfwm_compositor_settings.ui" line="42"/>
@@ -633,7 +663,7 @@
         <translation>Zamknij</translation>
     </message>
     <message>
-        <location filename="xfwm_compositor_settings.cpp" line="38"/>
+        <location filename="xfwm_compositor_settings.cpp" line="39"/>
         <source>Xfwm Compositor Settings</source>
         <translation>Ustawienia kompozytora Xfwm</translation>
     </message>
